@@ -1,15 +1,23 @@
 <?php
+/**
+ * Copyright 1999-2015 Horde LLC (http://www.horde.org/)
+ *
+ * See the enclosed file COPYING for license information (LGPL). If you
+ * did not receive this file, see http://www.horde.org/licenses/lgpl21.
+ *
+ * @author   Chuck Hagenbuch <chuck@horde.org>
+ * @author   Jon Parise <jon@horde.org>
+ * @category Horde
+ * @license  http://www.horde.org/licenses/lgpl21 LGPL
+ * @package  Browser
+ */
+
 /**
  * This provides capability information for the current web client.
  *
  * Browser identification is performed by examining the HTTP_USER_AGENT
  * environment variable provided by the web server.
  *
- * Copyright 1999-2014 Horde LLC (http://www.horde.org/)
- *
- * See the enclosed file COPYING for license information (LGPL). If you
- * did not receive this file, see http://www.horde.org/licenses/lgpl21.
- *
  * @todo     http://ajaxian.com/archives/parse-user-agent
  * @author   Chuck Hagenbuch <chuck@horde.org>
  * @author   Jon Parise <jon@horde.org>
@@ -75,9 +83,6 @@ class Horde_Browser
      */
     protected $_robotAgents = array(
         /* The most common ones. */
-        'Googlebot',
-        'msnbot',
-        'bingbot',
         'Slurp',
         'Yahoo',
         /* The rest alphabetically. */
@@ -85,20 +90,14 @@ class Horde_Browser
         'Arachnoidea',
         'ArchitextSpider',
         'Ask Jeeves',
-        'B-l-i-t-z-Bot',
         'Baiduspider',
-        'BecomeBot',
         'cfetch',
         'ConveraCrawler',
         'ExtractorPro',
         'FAST-WebCrawler',
-        'FDSE robot',
         'fido',
         'findlinks',
         'Francis',
-        'geckobot',
-        'Gigabot',
-        'Girafabot',
         'grub-client',
         'Gulliver',
         'HTTrack',
@@ -106,7 +105,6 @@ class Horde_Browser
         'iaskspider',
         'iCCrawler',
         'InfoSeek',
-        'kinjabot',
         'KIT-Fireball',
         'larbin',
         'LEIA',
@@ -114,24 +112,15 @@ class Horde_Browser
         'lwp-trivial',
         'Lycos_Spider',
         'Mediapartners-Google',
-        'MSRBOT',
         'MuscatFerret',
-        'NaverBot',
-        'OmniExplorer_Bot',
-        'polybot',
         'Pompos',
-        'RufusBot',
         'Scooter',
-        'Seekbot',
         'sogou spider',
         'sproose',
         'Teoma',
-        'TheSuBot',
-        'TurnitinBot',
         'Twiceler',
         'Ultraseek',
         'Vagabondo/Kliksafe',
-        'ViolaBot',
         'voyager',
         'W3C-checklink',
         'webbandit',
@@ -835,6 +824,10 @@ class Horde_Browser
      */
     public function isRobot()
     {
+        if (preg_match('/bot/i', $this->_agent)) {
+            return true;
+        }
+
         if (is_null($this->_robotAgentRegexp)) {
             $regex = array();
             foreach ($this->_robotAgents as $r) {
@@ -1069,7 +1062,7 @@ class Horde_Browser
         }
 
         $filesize = ini_get('upload_max_filesize');
-        switch (strtolower(substr($filesize, -1, 1))) {
+        switch (Horde_String::lower(substr($filesize, -1, 1))) {
         case 'k':
             $filesize = intval(floatval($filesize) * 1024);
             break;
@@ -1088,7 +1081,7 @@ class Horde_Browser
         }
 
         $postsize = ini_get('post_max_size');
-        switch (strtolower(substr($postsize, -1, 1))) {
+        switch (Horde_String::lower(substr($postsize, -1, 1))) {
         case 'k':
             $postsize = intval(floatval($postsize) * 1024);
             break;
